==> demoniac-0.3.tar.gz: demoniac-0.3/libfx/genericoption.h <==
/*
 * Calodox Demoniac
 * Copyright (C) 2001 Julien Pilet
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *  
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * GenericOptions code for DemoNiac
 * Leto/calodox, 6.2001
 */

#ifndef _GENERICOPTION_H_
#define _GENERICOPTION_H_

#include <gtk/gtk.h>
#include <fx.h>
#include <matvect.h>
#include "saver.h"
#include "loader.h"
#include "track.h"

class FXInstance;

class GenericOption {
public:
	// Constructor. Called only by sub-class constructors.
	GenericOption(FXInstance *owner, char *name, char *defName, int flags);

        /* Draw the dialog component corresponding
	 * to the option type using GLUI
	 */
	GtkBox *drawLabel(GtkBox *box);
	virtual void draw(GtkBox *box)=0;
	virtual void update()=0;
	virtual void updateGui() = 0;
	virtual void computeValue(int time)=0;
	virtual void save(Saver *s)=0;
	virtual void load(Loader *l)=0;
	virtual ~GenericOption() { delete[] name; }

	// FXInstance which owns this option
	FXInstance *owner;

	// name of this option
	char *name;

	// flags (see fx.h)
	int flags;

	Track *track;

	OptVal value;

	// that's ugly. don't know how to do it :(
	GtkWidget *interpMenuItem[4]; 

	// should we ignore callbacks ?
	bool ignore;

	void drawInterp(GtkBox *box); 
	void setName(const char *newName, const char *def);
};

gint cbInterpolator(GtkWidget *widget, gpointer data);

#endif

==> demoniac-0.4.tar.gz: demoniac-0.4/libfx/genericoption.h <==
/*
 * Calodox Demoniac
 * Copyright (C) 2001 Julien Pilet
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *  
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * GenericOptions code for DemoNiac
 * Leto/calodox, 6.2001
 */

#ifndef _GENERICOPTION_H_
#define _GENERICOPTION_H_

#include <gtk/gtk.h>
#include <fx.h>
#include <matvect.h>
#include "saver.h"
#include "loader.h"
#include "track.h"

class FXInstance;

class GenericOption {
public:
	//! Constructor. Called only by sub-class constructors.
	GenericOption(FXInstance *owner, char *name, char *defName, int flags);

    /*! Draw the dialog component corresponding
	 * to the option type using GLUI
	 */
	GtkBox *drawLabel(GtkBox *box);
	virtual void draw(GtkBox *box)=0;
	virtual void update()=0;
	virtual void updateGui() = 0;
	virtual void computeValue(int time)=0;
	virtual void save(Saver *s)=0;
	virtual void load(Loader *l)=0;
	virtual ~GenericOption() { delete[] name; }

	//! FXInstance which owns this option
	FXInstance *owner;

	// name of this option
	char *name;

	//! flags (see fx.h)
	int flags;

	Track *track;

	OptVal value;

	//! tree node, used by TrackDlg.
	GtkWidget *treeItem;

	// should we ignore callbacks ?
	bool ignore;

	void setName(const char *newName, const char *def);
};

#endif
